==> icecat-6.0.2-2.tar.bz2: icecat-6.0.2-2/ipc/ipdl/test/cxx/TestSelfManageRoot.h <==
#ifndef mozilla__ipdltest_TestSelfManageRoot_h
#define mozilla__ipdltest_TestSelfManageRoot_h 1

#include "mozilla/_ipdltest/IPDLUnitTests.h"

#include "mozilla/_ipdltest/PTestSelfManageRootParent.h"
#include "mozilla/_ipdltest/PTestSelfManageRootChild.h"
#include "mozilla/_ipdltest/PTestSelfManageParent.h"
#include "mozilla/_ipdltest/PTestSelfManageChild.h"


namespace mozilla {
namespace _ipdltest {

//-----------------------------------------------------------------------------
// Parent side

class TestSelfManageParent :
    public PTestSelfManageParent
{
public:
    TestSelfManageParent() {
        MOZ_COUNT_CTOR(TestSelfManageParent);
    }
    virtual ~TestSelfManageParent() {
        MOZ_COUNT_DTOR(TestSelfManageParent);
    }

    ActorDestroyReason mWhy;

protected:    
    NS_OVERRIDE
    virtual PTestSelfManageParent* AllocPTestSelfManage() {
        return new TestSelfManageParent();
    }

    NS_OVERRIDE
    virtual bool DeallocPTestSelfManage(PTestSelfManageParent* a) {
        return true;
    }

    NS_OVERRIDE
    virtual void ActorDestroy(ActorDestroyReason why) {
        mWhy = why;
    }
};

class TestSelfManageRootParent :
    public PTestSelfManageRootParent
{
public:
    TestSelfManageRootParent() {
        MOZ_COUNT_CTOR(TestSelfManageRootParent);
    }
    virtual ~TestSelfManageRootParent() {
        MOZ_COUNT_DTOR(TestSelfManageRootParent);
    }

    void Main();

protected:    
    NS_OVERRIDE
    virtual PTestSelfManageParent* AllocPTestSelfManage() {
        return new TestSelfManageParent();
    }

    NS_OVERRIDE
    virtual bool DeallocPTestSelfManage(PTestSelfManageParent* a) {
        return true;
    }

    NS_OVERRIDE
    virtual void ActorDestroy(ActorDestroyReason why)
    {
        if (NormalShutdown != why)
            fail("unexpected destruction!");  
        passed("ok");
        QuitParent();
    }
};

//-----------------------------------------------------------------------------
// Child side

class TestSelfManageChild :
    public PTestSelfManageChild
{
public:
    TestSelfManageChild() {
        MOZ_COUNT_CTOR(TestSelfManageChild);
    }
    virtual ~TestSelfManageChild() {
        MOZ_COUNT_DTOR(TestSelfManageChild);
    }

protected:    
    NS_OVERRIDE
    virtual PTestSelfManageChild* AllocPTestSelfManage() {
        return new TestSelfManageChild();
    }

    NS_OVERRIDE
    virtual bool DeallocPTestSelfManage(PTestSelfManageChild* a) {
        delete a;
        return true;
    }

    NS_OVERRIDE
    virtual void ActorDestroy(ActorDestroyReason why) { }
};

class TestSelfManageRootChild :
    public PTestSelfManageRootChild
{
public:
    TestSelfManageRootChild() {
        MOZ_COUNT_CTOR(TestSelfManageRootChild);
    }
    virtual ~TestSelfManageRootChild() {
        MOZ_COUNT_DTOR(TestSelfManageRootChild);
    }

    void Main();

protected:    
    NS_OVERRIDE
    virtual PTestSelfManageChild* AllocPTestSelfManage() {
        return new TestSelfManageChild();
    }

    NS_OVERRIDE
    virtual bool DeallocPTestSelfManage(PTestSelfManageChild* a) {
        delete a;
        return true;
    }

    NS_OVERRIDE
    virtual void ActorDestroy(ActorDestroyReason why)
    {
        if (NormalShutdown != why)
            fail("unexpected destruction!");  
        QuitChild();
    }
};

} // namespace _ipdltest
} // namespace mozilla


#endif // ifndef mozilla__ipdltest_TestSelfManageRoot_h

==> icecat-31.4.0.tar.bz2: icecat-31.4.0/ipc/ipdl/test/cxx/TestSelfManageRoot.h <==
#ifndef mozilla__ipdltest_TestSelfManageRoot_h
#define mozilla__ipdltest_TestSelfManageRoot_h 1

#include "mozilla/_ipdltest/IPDLUnitTests.h"

#include "mozilla/_ipdltest/PTestSelfManageRootParent.h"
#include "mozilla/_ipdltest/PTestSelfManageRootChild.h"
#include "mozilla/_ipdltest/PTestSelfManageParent.h"
#include "mozilla/_ipdltest/PTestSelfManageChild.h"


namespace mozilla {
namespace _ipdltest {

//-----------------------------------------------------------------------------
// Parent side

class TestSelfManageParent :
    public PTestSelfManageParent
{
public:
    TestSelfManageParent() {
        MOZ_COUNT_CTOR(TestSelfManageParent);
    }
    virtual ~TestSelfManageParent() {
        MOZ_COUNT_DTOR(TestSelfManageParent);
    }

    ActorDestroyReason mWhy;

protected:    
    virtual PTestSelfManageParent* AllocPTestSelfManageParent() MOZ_OVERRIDE {
        return new TestSelfManageParent();
    }

    virtual bool DeallocPTestSelfManageParent(PTestSelfManageParent* a) MOZ_OVERRIDE {
        return true;
    }

    virtual void ActorDestroy(ActorDestroyReason why) MOZ_OVERRIDE {
        mWhy = why;
    }
};

class TestSelfManageRootParent :
    public PTestSelfManageRootParent
{
public:
    TestSelfManageRootParent() {
        MOZ_COUNT_CTOR(TestSelfManageRootParent);
    }
    virtual ~TestSelfManageRootParent() {
        MOZ_COUNT_DTOR(TestSelfManageRootParent);
    }

    static bool RunTestInProcesses() { return true; }
    static bool RunTestInThreads() { return true; }

    void Main();

protected:    
    virtual PTestSelfManageParent* AllocPTestSelfManageParent() MOZ_OVERRIDE {
        return new TestSelfManageParent();
    }

    virtual bool DeallocPTestSelfManageParent(PTestSelfManageParent* a) MOZ_OVERRIDE {
        return true;
    }

    virtual void ActorDestroy(ActorDestroyReason why) MOZ_OVERRIDE
    {
        if (NormalShutdown != why)
            fail("unexpected destruction!");  
        passed("ok");
        QuitParent();
    }
};

//-----------------------------------------------------------------------------
// Child side

class TestSelfManageChild :
    public PTestSelfManageChild
{
public:
    TestSelfManageChild() {
        MOZ_COUNT_CTOR(TestSelfManageChild);
    }
    virtual ~TestSelfManageChild() {
        MOZ_COUNT_DTOR(TestSelfManageChild);
    }

protected:    
    virtual PTestSelfManageChild* AllocPTestSelfManageChild() MOZ_OVERRIDE {
        return new TestSelfManageChild();
    }

    virtual bool DeallocPTestSelfManageChild(PTestSelfManageChild* a) MOZ_OVERRIDE {
        delete a;
        return true;
    }

    virtual void ActorDestroy(ActorDestroyReason why) MOZ_OVERRIDE { }
};

class TestSelfManageRootChild :
    public PTestSelfManageRootChild
{
public:
    TestSelfManageRootChild() {
        MOZ_COUNT_CTOR(TestSelfManageRootChild);
    }
    virtual ~TestSelfManageRootChild() {
        MOZ_COUNT_DTOR(TestSelfManageRootChild);
    }

    void Main();

protected:    
    virtual PTestSelfManageChild* AllocPTestSelfManageChild() MOZ_OVERRIDE {
        return new TestSelfManageChild();
    }

    virtual bool DeallocPTestSelfManageChild(PTestSelfManageChild* a) MOZ_OVERRIDE {
        delete a;
        return true;
    }

    virtual void ActorDestroy(ActorDestroyReason why) MOZ_OVERRIDE
    {
        if (NormalShutdown != why)
            fail("unexpected destruction!");  
        QuitChild();
    }
};

} // namespace _ipdltest
} // namespace mozilla


#endif // ifndef mozilla__ipdltest_TestSelfManageRoot_h
